#
# spec file for package hdf5
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?sles_version}
%define _mvapich2 1
%endif
%if 0%{?suse_version}
%define _openmpi 1
%endif

%define _mpi %{?_openmpi:openmpi} %{?_mvapich2:mvapich2}

Name:           hdf5
%define libname libhdf5
Version:        1.8.15
Release:        4.32
%define sonum   10
Summary:        Command-line programs for the HDF5 scientific data format
License:        BSD-3-Clause
Group:          Productivity/Scientific/Other
Url:            http://www.hdfgroup.org/HDF5/
Source0:        http://www.hdfgroup.org/ftp/HDF5/releases/hdf5-%{version}/src/hdf5-%{version}.tar.bz2
Source1:        baselibs.conf
Patch0:         hdf5-LD_LIBRARY_PATH.patch
Patch1:         hdf5-non_void_return.patch
# not really needed but we want to get noticed if hdf5 doesn' t know our host
Patch2:         hdf5-1.8.11-abort_unknown_host_config.patch
%ifarch %arm
Patch4:         hdf5-1.8.10-tests-arm.patch
%endif
Patch5:         hdf5-ldouble-ppc64le.patch
# PATCH-FIX-UPSTREAM hdf5-cpp-compilation-errors.patch badshah400@gmail.com -- Reverted a change to the H5api_adpt.h that caused compilation errors for the C++ HDF5 applications; patch taken from upstream svn
Patch6:         hdf5-cpp-compilation-errors.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
%if 0%{?suse_version} > 1140
BuildRequires:  gcc-fortran
%endif
BuildRequires:  krb5-devel
BuildRequires:  openssl-devel
BuildRequires:  zlib-devel
%if 0%{?suse_version} >= 1110
BuildRequires:  fdupes
%endif
%if 0%{?_openmpi}
BuildRequires:  openmpi-devel
%endif
%if 0%{?_mvapich2}
BuildRequires:  mvapich2-devel
%endif
Requires:       %{libname}-%{sonum} = %{version}
Requires:       %{libname}_hl%{sonum} = %{version}

%description
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains utility functions for working with HDF5 files.

%package -n %{name}-openmpi
Summary:        Command-line programs for the HDF5 scientific data format
Group:          Productivity/Scientific/Other
Requires:       %{libname}-%{sonum}-openmpi = %{version}
Requires:       %{libname}_hl%{sonum}-openmpi = %{version}

%description -n %{name}-openmpi
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains the openmpi version utility functions for working
with HDF5 files.

%package -n %{name}-mvapich2
Summary:        Command-line programs for the HDF5 scientific data format
Group:          Productivity/Scientific/Other
Requires:       %{libname}-%{sonum}-mvapich2 = %{version}
Requires:       %{libname}_hl%{sonum}-mvapich2 = %{version}

%description -n %{name}-mvapich2
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains the mvapich2 version utility functions for working
with HDF5 files.

%package -n %{libname}-%{sonum}
Summary:        Shared libraries for the HDF5 scientific data format
Group:          Productivity/Scientific/Other
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname} = %{version}
Obsoletes:      %{libname} < %{version}

%description -n %{libname}-%{sonum}
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains the HDF5 runtime libraries.

%package -n %{libname}-%{sonum}-openmpi
Summary:        Shared libraries for the HDF5 scientific data format
Group:          Productivity/Scientific/Other
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname}-openmpi = %{version}
Obsoletes:      %{libname}-openmpi < %{version}

%description -n %{libname}-%{sonum}-openmpi
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains the openmpi version of the HDF5 runtime libraries.

%package -n %{libname}-%{sonum}-mvapich2
Summary:        Shared libraries for the HDF5 scientific data format
Group:          Productivity/Scientific/Other
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname}-mvapich2 = %{version}
Obsoletes:      %{libname}-mvapich2 < %{version}

%description -n %{libname}-%{sonum}-mvapich2
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains the mvapich2 version of the HDF5 runtime libraries.

%package -n %{libname}_hl%{sonum}
Summary:        High-level shared libraries for the HDF5 scientific data format
Group:          Productivity/Scientific/Other
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname}_hl = %{version}
Obsoletes:      %{libname}_hl < %{version}

%description -n %{libname}_hl%{sonum}
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains the the high-level HDF5 runtime libraries.

%package -n %{libname}_hl%{sonum}-openmpi
Summary:        High-level shared libraries for the HDF5 scientific data format
Group:          Productivity/Scientific/Other
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname}_hl-openmpi = %{version}
Obsoletes:      %{libname}_hl-openmpi < %{version}

%description -n %{libname}_hl%{sonum}-openmpi
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains the openmpi version of the high-level HDF5
runtime libraries.

%package -n %{libname}_hl%{sonum}-mvapich2
Summary:        High-level shared libraries for the HDF5 scientific data format
Group:          Productivity/Scientific/Other
# To avoid unresolvable errors due to multiple providers of the library
Provides:       %{libname}_hl-mvapich2 = %{version}
Obsoletes:      %{libname}_hl-mvapich2 < %{version}

%description -n %{libname}_hl%{sonum}-mvapich2
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains the mvapich2 version of the high-level HDF5
runtime libraries.

%package devel-data
Summary:        Development data files for %{name}
Group:          Development/Libraries/Other

%description devel-data
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains generic files needed to create projects that use
any version of HDF5.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       %{name}-devel-data = %{version}
# Required by Fortran programs?
Requires:       %{libname}-%{sonum} = %{version}
Requires:       %{libname}_hl%{sonum} = %{version}

%description devel
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving. 

This package contains all files needed to create projects that use
HDF5.

%package openmpi-devel
Summary:        Development files for %{name}-openmpi
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel-data = %{version}
Requires:       %{name}-openmpi = %{version}
# Required by Fortran programs?
Requires:       %{libname}-%{sonum}-openmpi = %{version}
Requires:       %{libname}_hl%{sonum}-openmpi = %{version}

%description openmpi-devel
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains all files needed to create projects that use
the openmpi version of HDF5.

%package mvapich2-devel
Summary:        Development files for %{name}-mvapich2
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel-data = %{version}
Requires:       %{name}-mvapich2 = %{version}
# Required by Fortran programs?
Requires:       %{libname}-%{sonum}-mvapich2 = %{version}
Requires:       %{libname}_hl%{sonum}-mvapich2 = %{version}

%description mvapich2-devel
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package contains all files needed to create projects that use
the mvapich2 version of HDF5.

%package  devel-static
Summary:        Static development files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name}-devel = %{version}

%description devel-static
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package provides the static libraries for HDF5.

%package  openmpi-devel-static
Summary:        Static development files for %{name}-openmpi
Group:          Development/Libraries/Parallel
Requires:       %{name}-openmpi-devel = %{version}

%description openmpi-devel-static
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package provides the static libraries for the openmpi version of HDF5.

%package  mvapich2-devel-static
Summary:        Static development files for %{name}-mvapich2
Group:          Development/Libraries/Parallel
Requires:       %{name}-mvapich2-devel = %{version}

%description mvapich2-devel-static
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package provides the static libraries for the mvapich2 version of HDF5.

%package examples
Summary:        Examples for %{name}
Group:          Documentation/Other
Requires:       %{libname}-%{sonum} = %{version}
Requires:       %{libname}_hl%{sonum} = %{version}

%description examples
HDF5 is a data model, library, and file format for storing and
managing data. It supports an unlimited variety of datatypes, and
is designed for flexible and efficient I/O and for high volume and
complex data. HDF5 is portable and is extensible, allowing
applications to evolve in their use of HDF5.

The HDF5 technology suite is designed to organize, store, discover,
access, analyze, share, and preserve diverse, complex data in
continuously evolving heterogeneous computing and storage environments.

HDF5 supports all types of data stored digitally, regardless of origin
or size. Petabytes of remote sensing data collected by satellites,
terabytes of computational results from nuclear testing models, and
megabytes of high-resolution MRI brain scans are stored in HDF5 files,
together with metadata necessary for efficient data sharing,
processing, visualization, and archiving.

This package provides examples of HDF5 library use.

%prep
%setup -q
# don't forget to increase sonum, see also baselibs.conf
LT_VERS_INTERFACE=$(sed -n 's/^ *LT_VERS_INTERFACE *= *//p' config/lt_vers.am)
test "%{sonum}" = "${LT_VERS_INTERFACE}" || exit 1
%patch0 -p1 -b .LD_LIBRARY_PATH
%patch1 -p0 -b .non_void_return
%patch2 -p0 -b .abort_unknown_host_config
%ifarch %arm
%patch4 -p0 -b .tests-arm
%endif
%patch5 -p1
%patch6 -p0

echo "prepare parallel builds: %_mpi"
for build_dir in build %_mpi; do
    mkdir $build_dir
    ln -s ../configure $build_dir
done

%build
export CC=gcc
export CXX=g++
export F9X=gfortran
# workaround for known gcc issue, see RELEASE.txt
if gcc --version |grep -q " 4\.[68]"; then
	export CFLAGS="${RPM_OPT_FLAGS/-O2/-O0}"
fi
%ifarch %arm
# we want to have useful H5_CFLAGS on arm too
test -e config/linux-gnueabi || cp config/linux-gnu config/linux-gnueabi
%endif

# NOTE: --enable-unsupported is required when --enable-fortran
# and/or --enable-cxx is enabled along with --enable-threadsafe.
# Building with thise combination results in thread-safe C 
# libraries and non-thread-safe fotran and/or C++ libraries. So 
# you have to explicitly allow building the thread-safe C 
# library and the non-thread-safe C++ and fortran libraries in 
# order to make sure people don't assume that their fotran or 
# C++ code is thread-safe.  Since our users are going to be 
# accessing this through other programs, this doesn't matter.

pushd build
%configure \
  --docdir=%{_docdir}/%{name} \
  --disable-dependency-tracking \
%if 0%{?suse_version} > 1140
  --enable-fortran \
  --enable-fortran2003 \
%endif
  --enable-unsupported \
  --enable-hl \
  --enable-shared \
  --enable-cxx \
  --enable-threadsafe \
  --with-pthread

make V=1 %{?_smp_mflags}
popd

for mpi in %_mpi;
do
pushd $mpi
export CC="%{_libdir}/mpi/gcc/$mpi/bin/mpicc"
export FC="%{_libdir}/mpi/gcc/$mpi/bin/mpif90"
export F77="%{_libdir}/mpi/gcc/$mpi/bin/mpif77"
export LD_LIBRARY_PATH="%{_libdir}/mpi/gcc/$mpi/%_lib"
%configure \
  --docdir=%{_docdir}/%{name} \
  --prefix=%{_libdir}/mpi/gcc/$mpi \
  --exec-prefix=%{_libdir}/mpi/gcc/$mpi \
  --bindir=%{_libdir}/mpi/gcc/$mpi/bin \
  --libdir=%{_libdir}/mpi/gcc/$mpi/%_lib \
  --datadir=%{_libdir}/mpi/gcc/$mpi/share \
  --includedir=%{_libdir}/mpi/gcc/$mpi/include \
  --disable-dependency-tracking \
%if 0%{?suse_version} > 1140
  --enable-fortran \
  --enable-fortran2003 \
%endif
  --enable-unsupported \
  --enable-hl \
  --enable-shared \
  --enable-threadsafe \
  --enable-parallel \
  --with-pthread

make %{?_smp_mflags}
popd
done

%install
# install serial and parallel builds, (the serial one will win in case of
# duplicate files)
for build_dir in %_mpi build; do
	make install DESTDIR="%buildroot" -C "$build_dir"
done

find "%buildroot/%{_libdir}" -type f -name "*.la" | xargs rm -f
find %{buildroot}%{_datadir}/hdf5_examples -type f \
                 | grep -v ".sh$" | xargs chmod 644
# delete examples from parallel builds
rm -rf %{buildroot}%{_libdir}/mpi/gcc/*/share/hdf5_examples
%if 0%{?suse_version} >= 1110
%fdupes -s %{buildroot}/%{_datadir}
%endif

# rpm macro for version checking
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat > %{buildroot}%{_sysconfdir}/rpm/macros.hdf5 <<EOF
#
# RPM macros for hdf5 packaging
#
%_hdf5_sonum  %{sonum}
%_hdf5_version  %{version}
EOF

%check
%if 0%{?qemu_user_space_build}
# default timeout is 1200 seconds
export HDF5_ALARM_SECONDS=3600
%endif
make -C build check
# ignore errors for parallel builds
export HDF5_Make_Ignore=yes
for mpi in %_mpi; do
    make -C $mpi check
done

%post -n %{libname}-%{sonum} -p /sbin/ldconfig
%postun -n %{libname}-%{sonum} -p /sbin/ldconfig

%post -n %{libname}_hl%{sonum} -p /sbin/ldconfig
%postun -n %{libname}_hl%{sonum} -p /sbin/ldconfig

%if 0%{?_openmpi}
%post -n %{libname}-%{sonum}-openmpi -p /sbin/ldconfig
%postun -n %{libname}-%{sonum}-openmpi -p /sbin/ldconfig

%post -n %{libname}_hl%{sonum}-openmpi -p /sbin/ldconfig
%postun -n %{libname}_hl%{sonum}-openmpi -p /sbin/ldconfig
%endif

%if 0%{?_mvapich2}
%post -n %{libname}-%{sonum}-mvapich2 -p /sbin/ldconfig
%postun -n %{libname}-%{sonum}-mvapich2 -p /sbin/ldconfig

%post -n %{libname}_hl%{sonum}-mvapich2 -p /sbin/ldconfig
%postun -n %{libname}_hl%{sonum}-mvapich2 -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%{_bindir}/gif2h5
%{_bindir}/h52gif
%{_bindir}/h5copy
%{_bindir}/h5debug
%{_bindir}/h5diff
%{_bindir}/h5dump
%{_bindir}/h5import
%{_bindir}/h5jam
%{_bindir}/h5ls
%{_bindir}/h5mkgrp
%{_bindir}/h5perf_serial
%{_bindir}/h5redeploy
%{_bindir}/h5repack
%{_bindir}/h5repart
%{_bindir}/h5stat
%{_bindir}/h5unjam

%files -n %{libname}-%{sonum}
%defattr(-,root,root)
%doc COPYING ACKNOWLEDGMENTS README.txt
%doc release_docs/HISTORY-1_0-1_8_0_rc3.txt
%doc release_docs/HISTORY-1_8.txt
%doc release_docs/RELEASE.txt
%defattr(0755,root,root)
%{_libdir}/libhdf5.so.*
%{_libdir}/libhdf5_cpp.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/libhdf5_fortran.so.*
%endif

%files -n libhdf5_hl%{sonum}
%defattr(0755,root,root)
%{_libdir}/libhdf5_hl.so.*
%{_libdir}/libhdf5_hl_cpp.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/libhdf5hl_fortran.so.*
%endif

%files devel-data
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/rpm/macros.hdf5

%files devel
%defattr(-,root,root)
%{_bindir}/h5c++
%{_bindir}/h5cc
%if 0%{?suse_version} > 1140
%{_bindir}/h5fc
%endif
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/*.settings
%if 0%{?suse_version} > 1140
%{_includedir}/*.mod
%endif

%files devel-static
%defattr(-,root,root)
%{_libdir}/*.a

%files examples
%defattr(-,root,root)
%{_datadir}/hdf5_examples

%if 0%{?_openmpi}
%files -n %{name}-openmpi
%defattr(-,root,root)
%{_libdir}/mpi/gcc/openmpi/bin/gif2h5
%{_libdir}/mpi/gcc/openmpi/bin/h52gif
%{_libdir}/mpi/gcc/openmpi/bin/h5copy
%{_libdir}/mpi/gcc/openmpi/bin/h5debug
%{_libdir}/mpi/gcc/openmpi/bin/h5diff
%{_libdir}/mpi/gcc/openmpi/bin/h5dump
%{_libdir}/mpi/gcc/openmpi/bin/h5import
%{_libdir}/mpi/gcc/openmpi/bin/h5jam
%{_libdir}/mpi/gcc/openmpi/bin/h5ls
%{_libdir}/mpi/gcc/openmpi/bin/h5mkgrp
%{_libdir}/mpi/gcc/openmpi/bin/h5perf
%{_libdir}/mpi/gcc/openmpi/bin/h5perf_serial
%{_libdir}/mpi/gcc/openmpi/bin/h5redeploy
%{_libdir}/mpi/gcc/openmpi/bin/h5repack
%{_libdir}/mpi/gcc/openmpi/bin/h5repart
%{_libdir}/mpi/gcc/openmpi/bin/h5stat
%{_libdir}/mpi/gcc/openmpi/bin/h5unjam
%{_libdir}/mpi/gcc/openmpi/bin/ph5diff

%files -n %{libname}-%{sonum}-openmpi
%defattr(-,root,root)
%doc COPYING ACKNOWLEDGMENTS README.txt
%doc release_docs/HISTORY-1_0-1_8_0_rc3.txt
%doc release_docs/HISTORY-1_8.txt
%doc release_docs/RELEASE.txt
%defattr(0755,root,root)
%{_libdir}/mpi/gcc/openmpi/%_lib/libhdf5.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/openmpi/%_lib/libhdf5_fortran.so.*
%endif

%files -n libhdf5_hl%{sonum}-openmpi
%defattr(0755,root,root)
%{_libdir}/mpi/gcc/openmpi/%_lib/libhdf5_hl.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/openmpi/%_lib/libhdf5hl_fortran.so.*
%endif

%files openmpi-devel
%defattr(-,root,root)
%{_libdir}/mpi/gcc/openmpi/bin/h5pcc
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/openmpi/bin/h5pfc
%endif
%{_libdir}/mpi/gcc/openmpi/include/*.h
%{_libdir}/mpi/gcc/openmpi/%_lib/*.so
%{_libdir}/mpi/gcc/openmpi/%_lib/*.settings
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/openmpi/include/*.mod
%endif

%files openmpi-devel-static
%defattr(-,root,root)
%{_libdir}/mpi/gcc/openmpi/%_lib/*.a
%endif

%if 0%{?_mvapich2}
%files -n %{name}-mvapich2
%defattr(-,root,root)
%{_libdir}/mpi/gcc/mvapich2/bin/gif2h5
%{_libdir}/mpi/gcc/mvapich2/bin/h52gif
%{_libdir}/mpi/gcc/mvapich2/bin/h5copy
%{_libdir}/mpi/gcc/mvapich2/bin/h5debug
%{_libdir}/mpi/gcc/mvapich2/bin/h5diff
%{_libdir}/mpi/gcc/mvapich2/bin/h5dump
%{_libdir}/mpi/gcc/mvapich2/bin/h5import
%{_libdir}/mpi/gcc/mvapich2/bin/h5jam
%{_libdir}/mpi/gcc/mvapich2/bin/h5ls
%{_libdir}/mpi/gcc/mvapich2/bin/h5mkgrp
%{_libdir}/mpi/gcc/mvapich2/bin/h5perf
%{_libdir}/mpi/gcc/mvapich2/bin/h5perf_serial
%{_libdir}/mpi/gcc/mvapich2/bin/h5redeploy
%{_libdir}/mpi/gcc/mvapich2/bin/h5repack
%{_libdir}/mpi/gcc/mvapich2/bin/h5repart
%{_libdir}/mpi/gcc/mvapich2/bin/h5stat
%{_libdir}/mpi/gcc/mvapich2/bin/h5unjam
%{_libdir}/mpi/gcc/mvapich2/bin/ph5diff

%files -n %{libname}-%{sonum}-mvapich2
%defattr(-,root,root)
%doc COPYING ACKNOWLEDGMENTS README.txt
%doc release_docs/HISTORY-1_0-1_8_0_rc3.txt
%doc release_docs/HISTORY-1_8.txt
%doc release_docs/RELEASE.txt
%defattr(0755,root,root)
%{_libdir}/mpi/gcc/mvapich2/%_lib/libhdf5.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/mvapich2/%_lib/libhdf5_fortran.so.*
%endif

%files -n libhdf5_hl%{sonum}-mvapich2
%defattr(0755,root,root)
%{_libdir}/mpi/gcc/mvapich2/%_lib/libhdf5_hl.so.*
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/mvapich2/%_lib/libhdf5hl_fortran.so.*
%endif

%files mvapich2-devel
%defattr(-,root,root)
%{_libdir}/mpi/gcc/mvapich2/bin/h5pcc
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/mvapich2/bin/h5pfc
%endif
%{_libdir}/mpi/gcc/mvapich2/include/*.h
%{_libdir}/mpi/gcc/mvapich2/%_lib/*.so
%{_libdir}/mpi/gcc/mvapich2/%_lib/*.settings
%if 0%{?suse_version} > 1140
%{_libdir}/mpi/gcc/mvapich2/include/*.mod
%endif

%files mvapich2-devel-static
%defattr(-,root,root)
%{_libdir}/mpi/gcc/mvapich2/%_lib/*.a
%endif

%changelog
* Fri Aug 21 2015 toddrme2178@gmail.com
- Currently the regular, openmpi, and mpivachi2 versions of the
  library packages all provide the exact same libraries.  So any
  package built against the -devel package will end up with an
  "unresolvable" build error because there are multiple versions
  of the library it can use. To avoid this, I have added generic
  provides for the library package so packages can depend on the
  version they really need, avoiding these build issues.
* Thu Aug 13 2015 badshah400@gmail.com
- Add hdf5-cpp-compilation-errors.patch: Reverts a change from
  v1.8.15 to H5api_adpt.h that caused compilation errors for C++
  HDF5 applications; patch taken from upstream svn.
* Mon Jul 27 2015 toddrme2178@gmail.com
- Update subpackage groups
- Make subpackage summaries and descriptions more consistent
- Provide rpm macros for version identification
- Spec file cleanups
* Mon Jul 27 2015 toddrme2178@gmail.com
- Use explicit library requirements to avoid ambiguities.
  Without this, packages that depend on hdf5 won't know which
  library to use.
* Thu Jul 23 2015 toddrme2178@gmail.com
- Fix baselibs.conf
* Wed Jul 22 2015 toddrme2178@gmail.com
- update to 1.8.15
  * New Features
    + Library
  - Added Memory Allocation Functions that Use the Library's Allocator
  - H5Pset_istore_k and H5Pset_sym_k added validation of "ik" to not
    exceed the max v1 btree entries (2 bytes) to these two routines.
  - Added Functions to Control the Value of H5PL_no_plugin_g without
    Using an Environment Variable
    + Parallel Library
  - Attached an attribute destroy callback to MPI_COMM_SELF that
    shuts down the HDF5 library when MPI_COMM_SELF is destroyed,
    in other words, on MPI_Finalize. This should fix several issues
    that users see when they forget to close HDF5 objects before
    + Fortran API
  - Added Global Variables. These new global variables are equivalent to
    the C definitions  without the '_F':
    o H5G_UDLINK_F
    o H5G_SAME_LOC_F
    o H5O_TYPE_UNKNOWN_F
    o H5O_TYPE_GROUP_F
    o H5O_TYPE_DATASET_F
    o H5O_NAMED_DATATYPE_F
    o H5O_TYPE_NTYPES_F
    + C++ API
  - New Wrappers for C Functions H5P[s/g]et_libver_bounds
  - New Wrappers to Get the Object Header's Version
  - New DataType Constructor
    + Support for New Platforms, Languages, and Compilers
  - Support for Linux 3.10.0-123.20.1.el7 added (LK - 2015/04/01)
  * Bug Fixes since HDF5-1.8.14
    + Library
  - Addition of Error Tracing Functionality to Several C API Calls
  - H5Rdereference Now Checks for HADDR_UNDEF or Uninitialized References
  - Fixed Bugs in H5Sextent_copy
    + Parallel Library
  - Fixed a Potential Memory Error
  - Parallel Test Problem Fixed
  - MPE Support
    + Tools
  - h5repack crashed on enumerated 8-bit type.
  - h52gif crashed non-8bit images.
  - perform/benchpar.c retired.
  - Source perform/ directory moved to tools/perform.
    + Fortran API
  - Fortran Fails with --enable-fortran2003 and Intel 15.x Compilers
  - h5tenum_insert_f Does Not Work with Default 8 Byte Integers
    (xlf compiler)
  - Some Fortran APIs Never Returned the Error State
  - Fixed h5pget_class_f
    + C++ API
  - Combined Two H5File::getObjCount Overloaded Methods
    The following two methods
    o ssize_t getObjCount(unsigned types) const;
    o ssize_t getObjCount() const;
    were combined into one:
    o ssize_t getObjCount(unsigned types = H5F_OBJ_ALL) const;
  - Many Warnings Were Removed
  - Functionality Deprecation
    The following two constructors of classes AbstractDs, IdComponent,
    H5Location, and H5Object are no longer appropriate after the data member
    "id" had been moved from IdComponent to the sub-classes in previous
    releases.
    o <Classname>(const hid_t h5_id);
    o <Classname>(const <Classname>& original);
    The copy constructors were no-op and removed in 1.8.15.  The other
    constructors will be removed from 1.10 release, and then from 1.8.17
    if their removal does not cause any problems.
    + High-Level APIs:
  - Suppress Warnings from Flex/Bison-generated Code
  - Changed hdf5_hl.h to Include the HDF5 Main Library "hdf5.h"
  - H5PTcreate_fl Does Not Convert to Memory Datatype
  - Fix for H5LT Attribute Functions
    + Fortran High-Level APIs:
  - Internal Library Fix for Missing Argument Declaration
- Build in thread-safe mode to allow parallel reads
  * These are only unsupported to avoid confusing casual users.
    The fotran and C++ libraries don't support thread-safe mode,
    while the C library does.  So you have to explicitly allow
    building the thread-safe C library and the non-thread-safe C++
    and fortran libraries in order to make sure only people who
    have done their research do so.  Since users are going to be
    accessing this through other programs, this doesn't matter.
- Build fortran 2003 libraries
- Rebase hdf5-non_void_return.patch
- Remove irrelevant hdf5-configure-long-double.patch
* Mon May 11 2015 dmueller@suse.com
- update hdf5-non_void_return.patch for GCC 5.x
* Tue Jan 13 2015 pth@suse.de
- Tag baselibs.conf as source.
* Fri Jan  9 2015 sweet_f_a@gmx.de
- fix typos in ChangeLog
* Wed Nov 19 2014 pgajdos@suse.com
- updated to 1.8.14:
  * bugfix release, see RELEASE.txt
* Mon Jun 23 2014 pgajdos@suse.com
- updated to 1.8.13:
  - Added an H5free_memory API call. This should be used to free memory
    that has been allocated by HDF5 API calls. H5Tget_member_name and
    H5Pget_class_name are two examples. The main motivation for this call
    is Windows, where it is common for application code and the HDF5 Library
    to be using different C run-time libraries (CRT). Using the new call
    ensures that the same CRT handles both the allocation and free. This
    new function can also be useful in any case where the library uses a
    different memory manager than the application, such as when a debug
    memory manager is in use or when the HDF5 Library is wrapped for use
    in a managed language like Python or Java. Fixes HDFFV-7710, 8519,
    and 8851. (DER - 2014/04/11)
  - The Core VFD (aka Memory VFD) can now be configured to track dirty
    regions in the file and only write out the changed regions on
    flush/close. Additionally, a "page aggregation" size can be set that
    will aggregate small writes into larger writes. For example, setting
    a 1 MiB page aggregation size will logically partition the the
    in-memory file into 1 MiB pages that will be written out in their
    entirety if even a single byte is dirtied. The feature is controlled
    via the new H5Pset/get_core_write_tracking() API call. A new
    "core_paged" target has been added to the check-vfd target in
    test/Makefile.am that exercises the feature over all HDF5 VFD-aware
    tests. (DER - 2014/04/12)
  - see http://www.hdfgroup.org/ftp/HDF5/current/src/hdf5-1.8.13-RELEASE.txt
    for more
- modified patches:
  * hdf5-LD_LIBRARY_PATH.patch
* Sun Jan  5 2014 matz@suse.de
- Detect IBM long double specialness on ppc64le and don't segfault
  int the testsuite when checking that type.
  Added patches:
  * hdf5-ldouble-ppc64le.patch
* Tue Nov 26 2013 pgajdos@suse.com
- update to 1.8.12:
  - Added a configuration option to change the default plugin path.
    The configure option is --with-default-plugindir=location.
    The cmake option is -DH5_DEFAULT_PLUGINDIR:PATH=location.
    HDFFV-8513.  (ADB 2013/09/04)
  - Renamed FFLAGS to FCFLAGS in configure. (ADB 2013/08/13)
  - CMake can now package a compressed examples file, the default for
    Windows binaries from HDF Group.  (ADB  - 2013/07/22)
  - h5repack: Added the ability to use plugin filters to read and write
    files. The option uses the filter number. HDFFV-8345
    (ADB - 2013/09/04).
  - h5dump: Added the option -N --any_path, which searches the file for
    paths that match the search path. HDFFV-7989 (ADB - 2013/08/12).
  - h5dump: Added the optional arg 0 to -A, which excludes attributes
    from display. HDFFV-8134 (ADB - 2013/08/01).
  - Added tutorial examples to C++/examples.  They can be installed by
    "make install-examples" and, in the installed directory, they can be
    executed by running the script file run-c++-ex.sh. (BMR - 2013/09/28)
  - A new class, H5::H5Location, is added to represent the location concept
    in the C library.  It is a base class to H5::H5File and H5::H5Ojbect,
    whose member functions are moved into H5::H5Location.  H5::H5File can
    now inherent those functions.  As a result, an H5::H5File object can have
    an attribute. (BMR - 2013/09/27)
  - Added wrappers for H5Rget_obj_type2 to retrieve the type of the object
    that an object reference points to. (BMR - 2013/09/27)
  H5O_type_t H5Location::getRefObjType(void *ref, H5R_type_t ref_type)
  - Added wrappers for H5Aexist to check whether an attribute exists given
    a name. (BMR - 2013/09/27)
  bool H5::H5Location::attrExists(const char* name)
  bool H5::H5Location::attrExists(const H5std_string& name)
  - Added a number of overloaded functions for convenience. (BMR - 2013/09/27)
  - bugfixes
  - see http://www.hdfgroup.org/ftp/HDF5/current/src/hdf5-1.8.12-RELEASE.txt
    for more
* Tue Sep 24 2013 schwab@suse.de
- hdf5-configure-long-double.patch: fix configure check for unsigned long
  long to long double conversion to not fail spuriously for 128bit long
  double
- Increase testsuite timeout for qemu user space build
* Fri Sep 13 2013 pgajdos@suse.com
- build with -O0 also for gcc 4.8
* Fri Jun 14 2013 sweet_f_a@gmx.de
- increase hdf5_libver to 8
* Wed Jun 12 2013 sweet_f_a@gmx.de
- use host config "linux-gnu" for arm (linux-gnueabi) to get useful
  H5_CFLAGS too
- add hdf5-1.8.11-abort_unknown_host_config.patch, to get noticed
  if hdf5 doesn' t know our host
- minimize hdf5-non_void_return.patch, false positives doesn't make
  problems anymore since now we have always -Wmissing-noreturn
- make verbose
- gcc 4.6.x needs -O0 on some systems
* Tue Jun 11 2013 sweet_f_a@gmx.de
- Update to 1.8.11, changes documented here:
  http://www.hdfgroup.org/HDF5/doc/ADGuide/Changes.html
- remove hdf5-fix_printf.patch, fixed by upstream
- use default CFLAGS (-O2) again if possible
* Fri Apr 12 2013 sweet_f_a@gmx.de
- Update to 1.8.10-patch1:
  * official important bug fixes for 1.8.10
  * see RELEASE.txt "Bug Fixes since HDF5-1.8.10"
* Sun Nov 18 2012 sweet_f_a@gmx.de
- Update to 1.8.10, changes documented here:
  http://www.hdfgroup.org/HDF5/doc/ADGuide/Changes.html
- remove hdf5-ph5diff.patch (fixed by upstream)
- add hdf5-fix_printf.patch
* Fri Nov 16 2012 sweet_f_a@gmx.de
- cosmetics, enable parallel build for suse only
- fix build for old findutils
* Mon Nov  5 2012 coolo@suse.com
- fixing baselibs.conf
* Wed Sep 26 2012 sweet_f_a@gmx.de
- make sure to install the examples from non-parallel build
* Mon Sep 24 2012 sweet_f_a@gmx.de
- don't use deprecated macro makeinstall
- enable test suite for parallel builds
- always build out of tree instead of copying sources
* Fri Sep  7 2012 scorot@free.fr
- parallel versions for openmpi and mvapich2
- add baselibs.conf
* Wed Jun 20 2012 sweet_f_a@gmx.de
- minor rpm portability build fixes
  - remove unused source file h5comp
  - enable all tests on ppc again (remove hdf5-1.8.8-tstlite.patch)
  - build fixes for arm
  * avoid some false positives "no-return-in-nonvoid-function"
  * disable some tests on arm only (hdf5-1.8.9-tests-arm.patch)
* Mon May 28 2012 ocefpaf@gmail.com
- Update to 1.8.9
  * Changes documented here:
  http://www.hdfgroup.org/HDF5/doc/ADGuide/Changes.html
* Mon Mar 12 2012 sweet_f_a@gmx.de
- install libhdf5.settings (bnc#751747)
- move executables h5cc and h5c++ to the devel package
* Sun Feb 19 2012 ocefpaf@gmail.com
- Removed "Fixup headers and scripts for multiarch".
* Wed Nov 30 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Accurate rpmgroup selection for shared library packages
* Tue Nov 29 2011 ocefpaf@gmail.com
- un-commented --with-pthread and --with-ssl.
* Mon Nov 28 2011 ocefpaf@gmail.com
- Update to 1.8.8
  * Add patch to avoid setting LD_LIBRARY_PATH
  * Add patch hdf5-non_void_return.patch
  * Fixed non_void_return (thanks to Boris Manojlovic).
  * Drop tstlite patch
  * drop ppc64 longdouble patch, not required anymore
  * Catch up with some Fedora modifications
  - Add rpm macro %%%%{_hdf5_version} for convenience
  * No Fortran modules for opensuse < 11.4 (Do not pass make check)
  New Features
  ============
    Configuration
  - ------------
  - Added the --enable-fortran2003 flag to enable Fortran2003 support
    in the HDF5 Fortran library. The flag should be used along with the
  - -enable-fortran flag and takes affect only when the Fortran compiler
    is Fortran2003 compliant. (EIP - 2011/11/14)
  - Added checks for clock_gettime and mach/mach_time.h to both configure and
    CMake.  This will support the move from gettimeofday to clock_gettime's
    monotonic timer in the profiling code in a future release.
    (DER - 2011/10/12)
    Library
  - ------
  - The Windows VFD code has been removed with the exception of the functions
    which set it (H5Pset_fapl_windows, for example).  Setting the Windows
    VFD now really sets the SEC2 VFD.  The WINDOWS_MAX_BUF and
    WINDOWS_USE_STDIO configuration options and #defines have also been
    removed. NOTE: Since the Windows VFD was a clone of the SEC2 VFD, this
    change should be transparent to users.
    (DER - 2011/10/12 - HDFFV-7740, HDFFV-7744)
  - H5Tcreate now supports the string type (fixed-length and variable-
    length). (SLU - 2011/05/20)
    Parallel Library
  - ---------------
  - Added new H5Pget_mpio_actual_chunk_opt_mode and
    H5Pget_mpio_actual_io_mode API routines for querying whether/how
    a collective I/O operation completed.  (QAK - 2011/10/12)
    Tools
  - ----
  - None
    High-Level APIs
  - --------------
  - Added the following Fortran wrappers for the Dimension Scale APIs:
    h5dsset_scale_f
    h5dsattach_scale_f
    h5dsdetach_scale_f
    h5dsis_attached_f
    h5dsis_scale_f
    h5dsset_label_f
    h5dsget_label_f
    h5dsget_scale_name_f
    h5dsget_num_scales_f
    (EIP for SB - 2011/10/13 - HDFFV-3797)
    Fortran API
  - ----------
  - The HDF5 Fortran library was enhanced to support the Fortran 2003 standard.
    The following features are available when the HDF5 library is configured
    using the --enable-fortran and --enable-fortran2003 configure flags AND
    if the Fortran compiler is Fortran 2003 compliant:
  - Subroutines overloaded with the C_PTR derived type:
    h5pget_f
    h5pget_fill_value_f
    h5pinsert_f
    h5pregister_f
    h5pset_f
    h5pset_fill_value_f
    h5rcreate_f
    h5rderefrence_f
    h5rget_name_f
    h5rget_obj_type_f
  - Subroutines overloaded with the C_PTR derived type
    and simplified signatures:
    h5aread_f
    h5awrite_f
    h5dread_f
    h5dwrite_f
  - New subroutines
    h5dvlen_reclaim_f
    h5literate_by_name_f
    h5literate_f
    h5ovisit_f
    h5tconvert_f
    h5pset_nbit_f
    h5pset_scaleoffset_f
  - Subroutines with additional optional parameters:
    h5pcreate_class_f
    (EIP - 2011/10/14)
    C++ API
  - ------
  - None
* Thu Jun  2 2011 ocefpaf@yahoo.com.br
- uncomment make check
* Tue May 24 2011 pgajdos@novell.com
- updated to 1.8.7
* Fri Apr 29 2011 pth@suse.de
- undrop package.
- Do type-punning using unions to be able to compile without
  - fno-strict-aliasing.
- Don't use macros in patch names.
- Use _cv_ in variables to be cached by configure.
* Thu May  7 2009 pgajdos@suse.cz
- fixed build with new gcc, see [bnc#501751]
* Mon Mar  2 2009 crrodriguez@suse.de
- save 9MB removing static libraries
* Tue Jan 13 2009 pgajdos@suse.cz
- updated to 1.8.2:
  - Upgraded libtool to version 2.2.6a. (MAM - 2008/10/15).
  - Added two new public routines: H5Pget_elink_fapl() and
    H5Pset_elink_fapl(). (see bug #1247) (VC - 2008/10/13)
  - Improved free space tracking in file to be faster. (QAK - 2008/10/06)
  - Added 'mounted' field to H5G_info_t struct. (QAK - 2008/07/15)
  - h5repack: added new options -u and -b to add a userblock to an HDF5
    file during the repack.  (PVN - 2008/08/26)
  - h5repack: added options -t and -a to call H5Pset_alignment while
    creating a repacked file. (PVN - 2008/08/29)
  - h5ls: added capability to traverse through external links when the -r
    (recursive) flag is given. (NAF - 2008/09/16)
  - h5ls: added -E option to enable traversal of external links.
    h5ls will not traverse external links without this flag being set.
    (NAF - 2008/10/06)
  - h5dump: when -b flag is used without a keyword after it, binary
    output defaults to NATIVE. MEMORY keyword was deprecated
    and replaced by NATIVE keyword. (PVN - 2008/10/30)
  - h5diff: returns 1 when file graphs differ by any object.
    Error return code was changed to 2 from -1.  (PVN - 2008/10/30)
  - h5import: TEXTFPE (scientific format) was deprecated. Use TEXTFP
    instead (PVN - 2008/10/30)
  - Added optional parameter 'mounted' to H5Gget_info_f,
    H5Gget_info_by_idx_f, H5Gget_info_by_name_f (MSB - 2008/09/24)
  - Added H5Tget_native_type_f (MSB - 2008/09/30)
  - These member functions were added as wrapper for H5Rdereference to
    replace the incorrect IdComponent::dereference().
    void H5Object::dereference(H5Object& obj, void* ref,
    H5R_type_t ref_type=H5R_OBJECT)
    void H5Object::dereference(H5File& h5file, void* ref,
    H5R_type_t ref_type=H5R_OBJECT)
    void H5Object::dereference(Attribute& obj, void* ref,
    H5R_type_t ref_type=H5R_OBJECT)
    In addition, these constructors were added to create the associated
    objects by way of dereference:
    DataSet(H5Object& obj, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataSet(H5File& file, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataSet(Attribute& attr, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    Group(H5Object& obj, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    Group(H5File& obj, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    Group(Attribute& attr, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataType(H5Object& obj, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataType(H5File& file, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    DataType(Attribute& attr, void* ref, H5R_type_t ref_type=H5R_OBJECT)
    (BMR - 2008/10/29)
- removed destdir.patch
* Mon Jan 12 2009 pgajdos@suse.cz
- fortran modules builds from now [bnc#457593]
* Tue Nov 11 2008 pgajdos@suse.cz
- fixing build of fortran interface moved to the future
* Wed Jul  2 2008 pgajdos@suse.cz
- updated to 1.8.1 [bnc#401626]
  * Enhanced group object management
  * Enhanced attribute management and more efficient meta data handling
  * Expanded datatype features
  * Creation order tracking and indexing
  * Improved meta data caching and cache control
  * UTF-8 encoding
  * New I/O filters: n-bit and scale+offset compression
  * New link (H5L) and object (H5O) interfaces and features
  * External and user-defined links
  * New high-level APIs:
    HDF5 Packet Table (H5PT) and HDF5 Dimension Scale (H5DS)
  * C++ and Fortran interfaces for older high-level APIs:
    H5Lite (H5LT), H5Image (H5IM), and H5Table (H5TB)
  * New and improved tools
- removed doc package (doc/html no longer provided with package)
- octave builds againist 1.6 compatibility stuff
* Wed May  7 2008 pgajdos@suse.cz
- repaired no-return-in-nonvoid-function
  (noreturn.patch)
* Mon Apr 28 2008 pgajdos@suse.cz
- repaired build for
  * ia64 (%%ifarch in hdf5.spec)
  * s390, s390x (s390.patch)
* Tue Mar 25 2008 pgajdos@suse.cz
- package moved from BS, project science
- needed by octave 3.0
